## What's Changed

### 修复

- 企业自部署飞书（自定义 domain）可以接收消息但无法发送消息的问题。
- 安装插件 Dialog 的深色样式问题。

### 优化

- 避免某些插件在流式响应结束后重d复发送消息的问题。

### 新增

- 支持在对话管理批量导出对话轨迹数据为 `jsonl` 格式文件。入口：WebUI -> 对话管理 -> 批量选中 -> 导出。
- 支持对 TTS（文本转语音）设置概率触发。
- （插件开发）支持在 schema 中对 float 和 int 类型设置 `slider` 滑块控件。例如 `slider: {min: 0, max: 1, step: 0.1}`。
- （插件开发）支持 key-value 存储功能。例如使用 `await self.put_kv_data("key", value)`, `await self.get_kv_data("key", default_value)` 和 `await self.delete_kv_data("key")`。